==> zio-aws-lexruntimev2_3-5.17.184.1-sources.jar: zio/aws/lexruntimev2/model/DialogAction.scala <==
package zio.aws.lexruntimev2.model
import zio.aws.lexruntimev2.model.primitives.NonEmptyString
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DialogAction(
    `type`: zio.aws.lexruntimev2.model.DialogActionType,
    slotToElicit: Optional[NonEmptyString] = Optional.Absent,
    slotElicitationStyle: Optional[zio.aws.lexruntimev2.model.StyleType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexruntimev2.model.DialogAction = {
    import DialogAction.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexruntimev2.model.DialogAction
      .builder()
      .`type`(`type`.unwrap)
      .optionallyWith(
        slotToElicit.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.slotToElicit)
      .optionallyWith(slotElicitationStyle.map(value => value.unwrap))(
        _.slotElicitationStyle
      )
      .build()
  }
  def asReadOnly: zio.aws.lexruntimev2.model.DialogAction.ReadOnly =
    zio.aws.lexruntimev2.model.DialogAction.wrap(buildAwsValue())
}
object DialogAction {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexruntimev2.model.DialogAction
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexruntimev2.model.DialogAction =
      zio.aws.lexruntimev2.model.DialogAction(
        `type`,
        slotToElicit.map(value => value),
        slotElicitationStyle.map(value => value)
      )
    def `type`: zio.aws.lexruntimev2.model.DialogActionType
    def slotToElicit: Optional[NonEmptyString]
    def slotElicitationStyle: Optional[zio.aws.lexruntimev2.model.StyleType]
    def getType
        : ZIO[Any, Nothing, zio.aws.lexruntimev2.model.DialogActionType] =
      ZIO.succeed(`type`)
    def getSlotToElicit: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("slotToElicit", slotToElicit)
    def getSlotElicitationStyle
        : ZIO[Any, AwsError, zio.aws.lexruntimev2.model.StyleType] =
      AwsError.unwrapOptionField("slotElicitationStyle", slotElicitationStyle)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexruntimev2.model.DialogAction
  ) extends zio.aws.lexruntimev2.model.DialogAction.ReadOnly {
    override val `type`: zio.aws.lexruntimev2.model.DialogActionType =
      zio.aws.lexruntimev2.model.DialogActionType.wrap(impl.`type`())
    override val slotToElicit: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.slotToElicit())
      .map(value => zio.aws.lexruntimev2.model.primitives.NonEmptyString(value))
    override val slotElicitationStyle
        : Optional[zio.aws.lexruntimev2.model.StyleType] = zio.aws.core.internal
      .optionalFromNullable(impl.slotElicitationStyle())
      .map(value => zio.aws.lexruntimev2.model.StyleType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexruntimev2.model.DialogAction
  ): zio.aws.lexruntimev2.model.DialogAction.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lexruntimev2_3-5.19.26.1-sources.jar: zio/aws/lexruntimev2/model/DialogAction.scala <==
package zio.aws.lexruntimev2.model
import zio.aws.lexruntimev2.model.primitives.NonEmptyString
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DialogAction(
    `type`: zio.aws.lexruntimev2.model.DialogActionType,
    slotToElicit: Optional[NonEmptyString] = Optional.Absent,
    slotElicitationStyle: Optional[zio.aws.lexruntimev2.model.StyleType] =
      Optional.Absent,
    subSlotToElicit: Optional[zio.aws.lexruntimev2.model.ElicitSubSlot] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lexruntimev2.model.DialogAction = {
    import DialogAction.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lexruntimev2.model.DialogAction
      .builder()
      .`type`(`type`.unwrap)
      .optionallyWith(
        slotToElicit.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.slotToElicit)
      .optionallyWith(slotElicitationStyle.map(value => value.unwrap))(
        _.slotElicitationStyle
      )
      .optionallyWith(subSlotToElicit.map(value => value.buildAwsValue()))(
        _.subSlotToElicit
      )
      .build()
  }
  def asReadOnly: zio.aws.lexruntimev2.model.DialogAction.ReadOnly =
    zio.aws.lexruntimev2.model.DialogAction.wrap(buildAwsValue())
}
object DialogAction {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lexruntimev2.model.DialogAction
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lexruntimev2.model.DialogAction =
      zio.aws.lexruntimev2.model.DialogAction(
        `type`,
        slotToElicit.map(value => value),
        slotElicitationStyle.map(value => value),
        subSlotToElicit.map(value => value.asEditable)
      )
    def `type`: zio.aws.lexruntimev2.model.DialogActionType
    def slotToElicit: Optional[NonEmptyString]
    def slotElicitationStyle: Optional[zio.aws.lexruntimev2.model.StyleType]
    def subSlotToElicit
        : Optional[zio.aws.lexruntimev2.model.ElicitSubSlot.ReadOnly]
    def getType
        : ZIO[Any, Nothing, zio.aws.lexruntimev2.model.DialogActionType] =
      ZIO.succeed(`type`)
    def getSlotToElicit: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("slotToElicit", slotToElicit)
    def getSlotElicitationStyle
        : ZIO[Any, AwsError, zio.aws.lexruntimev2.model.StyleType] =
      AwsError.unwrapOptionField("slotElicitationStyle", slotElicitationStyle)
    def getSubSlotToElicit: ZIO[
      Any,
      AwsError,
      zio.aws.lexruntimev2.model.ElicitSubSlot.ReadOnly
    ] = AwsError.unwrapOptionField("subSlotToElicit", subSlotToElicit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lexruntimev2.model.DialogAction
  ) extends zio.aws.lexruntimev2.model.DialogAction.ReadOnly {
    override val `type`: zio.aws.lexruntimev2.model.DialogActionType =
      zio.aws.lexruntimev2.model.DialogActionType.wrap(impl.`type`())
    override val slotToElicit: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.slotToElicit())
      .map(value => zio.aws.lexruntimev2.model.primitives.NonEmptyString(value))
    override val slotElicitationStyle
        : Optional[zio.aws.lexruntimev2.model.StyleType] = zio.aws.core.internal
      .optionalFromNullable(impl.slotElicitationStyle())
      .map(value => zio.aws.lexruntimev2.model.StyleType.wrap(value))
    override val subSlotToElicit
        : Optional[zio.aws.lexruntimev2.model.ElicitSubSlot.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.subSlotToElicit())
        .map(value => zio.aws.lexruntimev2.model.ElicitSubSlot.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lexruntimev2.model.DialogAction
  ): zio.aws.lexruntimev2.model.DialogAction.ReadOnly = new Wrapper(impl)
}
